<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_CA">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation type="obsolete">À propos</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Ajouter un marque-page</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Entrer un nom pour le marque-page et choisissez où le conserver.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Titre</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation type="unfinished">Ajouter un dossier</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nouveau dossier</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Marque-pages</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Retirer</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Ajouter un dossier</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Ouvrir dans un nouvel onglet</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Erreur pendant le chargement des marque-pages à la ligne %1, colonne %2:￼
%3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Barre d&apos;outils Marque-pages</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Ouvrir un fichier</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>%1 a été importé</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Enregistrer le fichier</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Erreur d&apos;exportation</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>Erreur de sauvegarde des marque-pages</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Retirer le marque-page</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Insérer un marque-page</translation>
    </message>
    <message>
        <source>Name Change</source>
        <translation type="obsolete">Changement de nom</translation>
    </message>
    <message>
        <source>Address Change</source>
        <translation type="obsolete">Changement d&apos;adresse</translation>
    </message>
    <message>
        <source>Bookmarks Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation type="unfinished">Changement de nom</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation type="unfinished">Changement d&apos;adresse</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Marque-page</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished">Ouvrir</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation type="unfinished">Ouvrir dans un nouvel &amp;onglet</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation type="unfinished">Ajouter un marque-page...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="unfinished">Marque-pages</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Il y a %1 fenêtres et %2 onglets ouverts.
Voulez-vous tout de même quitter?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Nouvelle fenêtre</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;Ouvrir un fichier...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Ouvrir une &amp;adresse...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>Enregistrer &amp;sous...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Importer des marque-pages...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Exporter les marque-pages...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>Ape&amp;rçu avant impression...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Im&amp;pression</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>Navigation en mode privé</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Édition</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Refaire</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Couper</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Co&amp;pier</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>C&amp;oller</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Rechercher</translation>
    </message>
    <message>
        <source>&amp;Find Next</source>
        <translation type="obsolete">Rechercher le &amp;suivant</translation>
    </message>
    <message>
        <source>&amp;Find Previous</source>
        <translation type="obsolete">Rechercher le p&amp;récédent</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation type="obsolete">&amp;Préférences</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Affichage</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>A&amp;rrêter</translation>
    </message>
    <message>
        <source>Reload Page</source>
        <translation type="obsolete">&amp;Recharger la page</translation>
    </message>
    <message>
        <source>&amp;Make Text Bigger</source>
        <translation type="obsolete">Agrandir le texte</translation>
    </message>
    <message>
        <source>&amp;Make Text Smaller</source>
        <translation type="obsolete">Réduire le texte</translation>
    </message>
    <message>
        <source>&amp;Make Content Bigger</source>
        <translation type="obsolete">Agrandir la page</translation>
    </message>
    <message>
        <source>&amp;Make Content Smaller</source>
        <translation type="obsolete">Réduire la page</translation>
    </message>
    <message>
        <source>&amp;Make Text Normal</source>
        <translation type="obsolete">Réinitialiser la taile du texte</translation>
    </message>
    <message>
        <source>&amp;Make Content Normal</source>
        <translation type="obsolete">Réinitialiser la taile de la page</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>Code s&amp;ource de la page</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;Historique</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Page précédente</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Page suivante</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Page d&apos;accueil</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Restaurer la dernière session</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Marque-pages</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation type="obsolete">Gérer les marque-pages</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Ajouter un marque-page...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenête</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Recherche Web</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Activer l&apos;&amp;inspecteur Web</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Arora</source>
        <translation type="obsolete">À propos d&apos;&amp;Arora</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Afficher la barre d&apos;état</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Masquer la barre d&apos;état</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Afficher la barre d&apos;outils</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Masquer la barre d&apos;outils</translation>
    </message>
    <message>
        <source>Show Bookmarks bar</source>
        <translation type="obsolete">Afficher la barre de marque-pages</translation>
    </message>
    <message>
        <source>Hide Bookmarks bar</source>
        <translation type="obsolete">Masquer la barre de marque-pages</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Ouvrir un fichier Web</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Fichier Web (*.html *.htm *.svg *.png *.gif *.svgz);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Imprimer le document</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Êtes-vous sûr de vouloir activer la navigation en mode privé?</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttonsto return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Lorsque la navigation en mode privé est activée, certaines actions concernant votre vie privée seront désactivées:&lt;ul&gt;&lt;li&gt; Les pages Web ne sont pas ajoutées à l&apos;historique.&lt;/li&gt;&lt;li&gt; Les téléchargements sont automatiquement retiré de la fenêtre des téléchargements.&lt;/li&gt;&lt;li&gt; Les nouveaux fichiers témoins ne sont pas conservés et les fichiers témoins déjà existant ne sont pas accessibles.&lt;/li&gt;&lt;li&gt; Les icônes de sites Web et la session ne sont pas enregistrés.&lt;/li&gt;&lt;li&gt; Les recherches ne sont pas ajoutées dans la liste des recherches récentes.&lt;/li&gt;&lt;/ul&gt;Jusqu&apos;à la fermeture de l&apos;écran, vous pouvez encore utiliser les boutons Page précédente et Page suivante.</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Êtes-vous sûr de vouloir fermer cette fenêtre? Il y a %1 onglets ouverts.</translation>
    </message>
    <message>
        <source>Page Source of %1</source>
        <translation type="obsolete">Code source de %1</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Inspecteur Web</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>L&apos;inspecteur Web ne fonctionne que pour les pages qui ont été chargées après son activation.  Voulez-vous recharcher toutes les pages?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Arrêter le chargement de la page en cours</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Recharger la page en cours</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;Effacer l&apos;information privée</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; Network cache is disabled.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Effacer les informations privées</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Vider les items suivants:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>Historique de navigation</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>Historique de téléchargement</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>Historique de recherche</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>Fichiers témoins</translation>
    </message>
    <message>
        <source>C&amp;ache</source>
        <translation type="obsolete">Mémoire cache</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>Icônes de sites Web</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>Effacer les informations privées</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished">Paramètres</translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Site Web</translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="obsolete">Statut</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Permettre</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Bloquer</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Permettre pour la session</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Site Web</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Chemin d&apos;accès</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Sécure</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expire</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Contenu</translation>
    </message>
    <message>
        <source>true</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>false</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Fichiers témoins</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Retirer</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Retirer tous les fichiers témoins</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Exceptions pour les fichiers témoins</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Nouvelle exception</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Domaine:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Bloquer</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Permettre pour la session</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Permettre</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Exceptions</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Tout retirer</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Vider la liste</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 items</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Formulaire</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Essayer à nouveau</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Interrompre</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Enregistrer le fichier</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Téléchargement annulé: %1</translation>
    </message>
    <message>
        <source>Error opening save file: %1</source>
        <translation type="obsolete">Erreur à l&apos;ouverture du fichier destination: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Erreur à l&apos;enregistrement: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Erreur réseau: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">secondes</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minutes</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation type="obsolete">- %4 %5 restant</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1 de %2 (%3/sec) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 de %2 - Interrompu</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="obsolete">octets</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="obsolete">kO</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="obsolete">MO</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation type="obsolete">1 téléchargement</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <translation type="obsolete">%1 téléchargements</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="unfinished">octets</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="unfinished">kO</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="unfinished">MO</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Retirer</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Tout retirer</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Montrer tout l&apos;historique</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Effacer l&apos;historique</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Plutôt aujourd&apos;hui</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="obsolete">%1 items</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>Choose language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No translation files are installed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Entrer le nombre d&apos;utilisateur et le mot de passe pour &quot;%1&quot; sur %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Se brancher au serveur mandataire &quot;%1&quot; en utilisant:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors?</source>
        <translation type="obsolete">Erreurs SSL:
%1
%2
Voulez-vous ignorer ses erreurs?</translation>
    </message>
    <message>
        <source>Do you want to accept all these certificates?</source>
        <translation type="obsolete">Voulez-vous accepter tous ces certificats?</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Nom</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation type="unfinished">Ouvrir un fichier</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Authentification requise</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;utilisateur:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation type="unfinished">Non trouvé</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Authentification au serveur mandataire</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Se brancher au serveur mandataire</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;utilisateur:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>Ce fichier n&apos;est pas un fichier XBEL version 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Titre inconnu</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Address</source>
        <translation type="obsolete">Adresse</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Fromulaire</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Paramètres</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Home:</source>
        <translation type="obsolete">Page d&apos;accueil:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Utiliser la page en cours</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation type="unfinished">Retirer les éléments de l&apos;historique:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Après une journée</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Après une semaine</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Après 2 semaines</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Après un mois</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Après un an</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Manuellement</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Ouvrir les liens provenant d&apos;applications:</translation>
    </message>
    <message>
        <source>In a tab in the current window</source>
        <translation type="obsolete">Dans un onglet dans la fenêtre en cours</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>Dans une nouvelle fenêtre</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Police par défaut:</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Sélectionner...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Police à espacement constant:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Vie privée</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Contenu Web</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Activer les plugiciels</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Activer le Javascript</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Fichier témoins</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Accepter les fichiers témoins:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Toujours</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Jamais</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Seulement des sites que vous visitez</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Exceptions...</translation>
    </message>
    <message>
        <source>Keep until:</source>
        <translation type="obsolete">Expiration:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>Lorsqu&apos;ils expirent</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Lorsque je quitte l&apos;application</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>Au plus tard dans 90 jours</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Fichiers témoins...</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Serveur mandataire</translation>
    </message>
    <message>
        <source>Enable proxy</source>
        <translation type="obsolete">Activer le serveur mandataire</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="obsolete">Hôte:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Nom d&apos;utilisateur:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Feuille de style:</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Demander le dossier de destination à chaque fois</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Utiliser ce dossier</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Édition</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished">&amp;Rechercher</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished">&amp;Affichage</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation type="obsolete">Nouvel onglet</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Dupliquer l&apos;onglet</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>Fermer l&apos;onglet</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Fermer les autres onglets</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Recharger l&apos;onglet</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Recharger tous les onglets</translation>
    </message>
    <message>
        <source>Show Tab Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nouvel onglet</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>Fermer l&apos;onglet</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Afficher l&apos;onglet suivant</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Afficher l&apos;onglet précédent</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Onglet récement fermés</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation type="obsolete">(Sans titre)</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Voulez-vous vraiment fermer cette page?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Vous avez modifié cette page et en fermant l&apos;onglet, vous allez perdre les modifications.
Voulez-vous vraiment fermer cette page?
</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>No Recent Searches</source>
        <translation>Aucune recherche récente</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Recherches récentes</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation type="unfinished">Effacer les recherches récentes</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Erreur au chargement de la page: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Ouvrir dans une &amp;nouvelle fenêtre</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Ouvrir dans un nouvel &amp;onglet</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Enregistrer le &amp;lien</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>Marquer le lien</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>Copier le lien</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Ouvrir l&apos;image dans une nouvelle fenêtre</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Ouvrir l&apos;image dans un nouvel onglet</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>Enregistrer l&apos;image</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Copier l&apos;image</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>Copier l&apos;adresse de l&apos;image</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Non trouvé</translation>
    </message>
</context>
</TS>
